summaryrefslogtreecommitdiffstats
path: root/pkg/commands/git_commands/commit.go
diff options
context:
space:
mode:
Diffstat (limited to 'pkg/commands/git_commands/commit.go')
-rw-r--r--pkg/commands/git_commands/commit.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/pkg/commands/git_commands/commit.go b/pkg/commands/git_commands/commit.go
index 5b36d7950..866634013 100644
--- a/pkg/commands/git_commands/commit.go
+++ b/pkg/commands/git_commands/commit.go
@@ -24,9 +24,9 @@ func NewCommitCommands(
}
}
-// RewordLastCommit renames the topmost commit with the given name
-func (self *CommitCommands) RewordLastCommit(name string) error {
- return self.cmd.New("git commit --allow-empty --amend --only -m " + self.cmd.Quote(name)).Run()
+// RewordLastCommit rewords the topmost commit with the given message
+func (self *CommitCommands) RewordLastCommit(message string) error {
+ return self.cmd.New("git commit --allow-empty --amend --only -m " + self.cmd.Quote(message)).Run()
}
// ResetToCommit reset to commit